==> FEA_code-0.1.0.crate: FEA_code-0.1.0/src/main.rs <==
use serde::{Deserialize, Serialize};
use serde_json::json;
use serde_json::{Result, Value};
use std::env::Args;
use std::fs;
use FEA_code::*;

fn get_args(data: &str) -> Result<(serde_json::Value)> {
    // let data = r#"
    // {
    //     "file_dem": "1.asc",
    //     "file_dat": "1.dat",
    //     "output": {
    //         "zbed":{
    //            "filter":0.15,
    //            "onepixel":20,
    //            "max":25.5,
    //            "min":0,
    //            "filename":"zbed.png"
    //         },
    //         "uv":{
    //             "filter_filed":"uv",
    //             "filter":0.01,
    //             "onepixel":40,
    //             "max":7.04,
    //             "min":-8.07,
    //             "filename":"uv.png",
    //             "type":"arrow"
    //         }
    //     }
    // }"#;

    let v: Value = serde_json::from_str(data)?;
    Ok(v)
}

fn main() {
    let args: Args = std::env::args();
    let mut args_i = 0;
    let mut file_input = String::from("");
    let mut kind = String::from("");
    for arg in args {
        print!("arg :{}\n", arg);
        if args_i == 2 {
            file_input = String::from(arg).clone();
            //break;
        } else if args_i == 1 {
            kind = String::from(arg).clone();

            //break;
        }
        args_i += 1;
    }

    if kind == "pollution" {
        yl_pollution(&file_input);
    } else if kind == "HUV" {
        yl_water(&file_input);
    } else {
        print!("程序需要两个参数，第一个参数是种类，第二个参数是josn选项");
        print!("第1个输入参数错误，目前支撑：pollution=水质，HUV=深度+u+v ");
    }
}

fn yl_pollution(input: &String) {
    let mut data: String = String::from("");
    data = fs::read_to_string(input).unwrap();
    // data = match data {
    //     Ok(ddd) => ddd,
    //     Err(e) => panic!("读取JSON文件错误 \n {}", e),
    // };
    // println!("文件打开成功：{:?}", data);

    let abc = match get_args(data.as_str()) {
        Ok(v) => v,
        Err(e) => panic!("Problem of input JSON: 检查是否正确 \n {:?}", e),
    };

    let filename = abc.get("file_dem").unwrap().as_str().unwrap();
    let filename1 = abc.get("file_dat").unwrap().as_str().unwrap();

    let output = abc.get("output").unwrap();
    let zbed = output.get("pollution").unwrap();
    let zbed_filename = zbed.get("filename").unwrap().as_str().unwrap();
    let zbed_one_pixel_upto = zbed.get("onepixel").unwrap().as_i64().unwrap() as i32;
    let zbed_filter_f64 = zbed.get("filter").unwrap().as_f64().unwrap();
    // let zbed_filter_f64 = zbed_filter_str.parse::<f64>().unwrap();
    let mut z_max = zbed.get("max").unwrap().as_f64().unwrap();
    let mut z_min = zbed.get("min").unwrap().as_f64().unwrap();
    let z_type = zbed.get("type").unwrap().as_str().unwrap();
    let z_global_MM = zbed.get("global_MM").unwrap().as_bool().unwrap();

    //=======================================================================
    //=== 输入参数
    // let filename = "1.asc";
    // let filename1 = "1.dat";

    // let zbed_filename = "zbed.png";
    // let uv_filename = "uv.png";

    // let one_pixel_upto = 40;
    // let filter = 0.01;

    // let type_cm = true;
    // let type_arrow = true;
    //=======================================================================

    let (list, rows, cols) = get_dem(filename);
    let z = get_1data_from_file(filename1, cols + 2, rows + 2);

    //=======================================================================
    //=== 输入 max ,min of z,u ,v ,uv
    // let (z_max, z_min) = get_MM(&z, &list, cols, rows);
    // let (u_max, u_min) = get_MM(&u, &list, cols, rows);
    // let (v_max, v_min) = get_MM(&v, &list, cols, rows);
    // // print!("v.max:{},v.min:{}\n", v_max, v_min);

    // let uv_max: f64;
    // let uv_min: f64;
    // if (u_max > v_max) {
    //     uv_max = u_max;
    // } else {
    //     uv_max = v_max;
    // }

    // if (u_min < v_min) {
    //     uv_min = u_min;
    // } else {
    //     uv_min = v_min;
    // }
    //=======================================================================

    if z_global_MM == false {
        (z_max, z_min) = get_MM(&z, &list, cols, rows);
    }
    write_image_CM(
        &z,
        &list,
        z_max,
        z_min,
        cols,
        rows,
        zbed_one_pixel_upto,
        zbed_filter_f64,
        zbed_filename,
        "cm",
    );
}

fn yl_water(file_input: &String) {
    let mut data: String = String::from("");
    data = fs::read_to_string(file_input).unwrap();
    // data = match data {
    //     Ok(ddd) => ddd,
    //     Err(e) => panic!("读取JSON文件错误 \n {}", e),
    // };
    // println!("文件打开成功：{:?}", data);

    let abc = match get_args(data.as_str()) {
        Ok(v) => v,
        Err(e) => panic!("Problem of input JSON: 检查是否正确 \n {:?}", e),
    };

    let filename = abc.get("file_dem").unwrap().as_str().unwrap();
    let filename1 = abc.get("file_dat").unwrap().as_str().unwrap();

    let output = abc.get("output").unwrap();

    let zbed = output.get("zbed").unwrap();
    let zbed_filename = zbed.get("filename").unwrap().as_str().unwrap();
    let zbed_one_pixel_upto = zbed.get("onepixel").unwrap().as_i64().unwrap() as i32;
    let zbed_filter_f64 = zbed.get("filter").unwrap().as_f64().unwrap();
    // let zbed_filter_f64 = zbed_filter_str.parse::<f64>().unwrap();
    let mut z_max = zbed.get("max").unwrap().as_f64().unwrap();
    let mut z_min = zbed.get("min").unwrap().as_f64().unwrap();
    let z_type = zbed.get("type").unwrap().as_str().unwrap();
    let z_global_MM = zbed.get("global_MM").unwrap().as_bool().unwrap();

    let uv_obj = output.get("uv");
    let uv_bool = match uv_obj {
        Some(b) => true,
        None => false,
    };
    print!("uv is object ={uv_bool}\n");
    let mut uv;
    let mut uv_filename = "asdfa";
    let mut uv_one_pixel_upto = 1;
    let mut uv_filter_f64 = 0.0;

    let mut uv_max = 0.0;
    let mut uv_min = 0.0;
    let mut uv_type: &str = "";
    let mut uv_filter_filed = "z";
    let mut uv_global_MM = false;
    if uv_bool {
        uv = output.get("uv").unwrap();
        uv_filename = uv.get("filename").unwrap().as_str().unwrap();
        uv_one_pixel_upto = uv.get("onepixel").unwrap().as_i64().unwrap() as i32;
        uv_filter_f64 = uv.get("filter").unwrap().as_f64().unwrap();
        // let uv_filter_f64 = uv_filter_str.parse::<f64>().unwrap();
        uv_max = uv.get("max").unwrap().as_f64().unwrap();
        uv_min = uv.get("min").unwrap().as_f64().unwrap();
        uv_type = uv.get("type").unwrap().as_str().unwrap();
        uv_filter_filed = uv.get("filter_filed").unwrap().as_str().unwrap();
        uv_global_MM = zbed.get("global_MM").unwrap().as_bool().unwrap();
    }
    //=======================================================================
    //=== 输入参数
    // let filename = "1.asc";
    // let filename1 = "1.dat";

    // let zbed_filename = "zbed.png";
    // let uv_filename = "uv.png";

    // let one_pixel_upto = 40;
    // let filter = 0.01;

    // let type_cm = true;
    // let type_arrow = true;
    //=======================================================================

    let (list, rows, cols) = get_dem(filename);
    let (z, u, v) = get_data_from_file(filename1, cols + 2, rows + 2);

    //=======================================================================
    //=== 输入 max ,min of z,u ,v ,uv
    if z_global_MM == false {
        (z_max, z_min) = get_MM(&z, &list, cols, rows);
    }
    if uv_global_MM == false {
        let (u_max, u_min) = get_MM(&u, &list, cols, rows);
        let (v_max, v_min) = get_MM(&v, &list, cols, rows);
        if (u_max > v_max) {
            uv_max = u_max;
        } else {
            uv_max = v_max;
        }

        if (u_min < v_min) {
            uv_min = u_min;
        } else {
            uv_min = v_min;
        }
        // print!("v.max:{},v.min:{}\n", v_max, v_min);
    }

    //=======================================================================
    println!("z max :{z_max},min:{z_min}\n UV_max:{uv_max},min:{uv_min}\n");
    write_image_CM(
        &z,
        &list,
        z_max,
        z_min,
        cols,
        rows,
        zbed_one_pixel_upto,
        zbed_filter_f64,
        zbed_filename,
        "blue",
    );
    print!("start UV  cm\n");
    if uv_bool {
        let mut f_list = z.clone();
        let mut f_max = z_max;
        let mut f_min = z_min;
        if uv_filter_filed == "uv" {
            f_list = get_vec2_array_M(&u, &v);
            f_max = uv_max;
            f_min = uv_min;
        }

        if uv_type == "arrow" {
            write_image_arrow(
                &u,
                &v,
                &list,
                uv_max,
                uv_min,
                // u_max,
                // u_min,
                // v_max,
                // v_min,
                cols,
                rows,
                uv_one_pixel_upto,
                uv_filename,
                &f_list,
                f_max,
                f_min,
                uv_filter_f64,
            );
        } else {
            write_image_CM(
                &z,
                &list,
                uv_max,
                uv_min,
                cols,
                rows,
                uv_one_pixel_upto,
                uv_filter_f64,
                uv_filename,
                "cm",
            );
        }
    }
}

==> FEA_code-0.1.1.crate: FEA_code-0.1.1/src/main.rs <==
use serde::{Deserialize, Serialize};
use serde_json::json;
use serde_json::{Result, Value};
use std::env::Args;
use std::fs;
use FEA_code::*;

fn get_args(data: &str) -> Result<(serde_json::Value)> {
    // let data = r#"
    // {
    //     "file_dem": "1.asc",
    //     "file_dat": "1.dat",
    //     "output": {
    //         "zbed":{
    //            "filter":0.15,
    //            "onepixel":20,
    //            "max":25.5,
    //            "min":0,
    //            "filename":"zbed.png"
    //         },
    //         "uv":{
    //             "filter_filed":"uv",
    //             "filter":0.01,
    //             "onepixel":40,
    //             "max":7.04,
    //             "min":-8.07,
    //             "filename":"uv.png",
    //             "type":"arrow"
    //         }
    //     }
    // }"#;

    let v: Value = serde_json::from_str(data)?;
    Ok(v)
}

fn main() {
    let args: Args = std::env::args();
    let mut args_i = 0;
    let mut file_input = String::from("");
    let mut kind = String::from("");
    for arg in args {
        print!("arg :{}\n", arg);
        if args_i == 2 {
            file_input = String::from(arg).clone();
            //break;
        } else if args_i == 1 {
            kind = String::from(arg).clone();

            //break;
        }
        args_i += 1;
    }

    if kind == "pollution" {
        yl_pollution(&file_input);
    } else if kind == "HUV" {
        yl_water(&file_input);
    } else if kind == "tecplot_SN" {
        tecplot_CM(&file_input);
    } else {
        print!("程序需要两个参数，第一个参数是种类，第二个参数是josn选项\n");
        print!("第1个输入参,目前支持:pollution=水质;HUV=深度+u+v \n");
        print!("                     tecplotc格式;tecplot_SN \n");
        print!("第2个输入参数是JSON文件,详见readme.txt \n");
    }
}
fn tecplot_CM(input: &String) {
    let mut data: String = String::from("");
    data = fs::read_to_string(input).unwrap();
    // data = match data {
    //     Ok(ddd) => ddd,
    //     Err(e) => panic!("读取JSON文件错误 \n {}", e),
    // };
    // println!("文件打开成功：{:?}", data);

    let abc = match get_args(data.as_str()) {
        Ok(v) => v,
        Err(e) => panic!("Problem of input JSON: 检查是否正确 \n {:?}", e),
    };

    let filename_sn = abc.get("file_dat").unwrap().as_str().unwrap();
    let input = abc.get("output").unwrap().as_object().unwrap();
    let (list, list_v, cols, rows) = tecplot::get_tecplot_SN(filename_sn);

    for (k, v) in input {
        // if k == "output"
        {
            let zbed = v;
            let filed = k;
            let zbed_filename = zbed.get("filename").unwrap().as_str().unwrap();
            let zbed_one_pixel_upto = zbed.get("onepixel").unwrap().as_u64().unwrap();
            let zbed_filter_f64 = zbed.get("filter").unwrap().as_f64().unwrap();
            let mut z_max = zbed.get("max").unwrap().as_f64().unwrap();
            let mut z_min = zbed.get("min").unwrap().as_f64().unwrap();
            let z_type = zbed.get("type").unwrap().as_str().unwrap();
            let z_global_MM = zbed.get("global_MM").unwrap().as_bool().unwrap();

            let index = tecplot::get_index_from_value(list_v.clone(), filed);
            let el_x = tecplot::get_index_from_value(list_v.clone(), "x");
            let el_y = tecplot::get_index_from_value(list_v.clone(), "y");
            let (w, h) =
                tecplot::get_one_element_WH(&list, cols as usize, rows as usize, el_x, el_y);
            if index == 999999 {
                panic!(" 未找到{k}的属性\n");
            }
            if z_global_MM == false {
                (z_max, z_min) = tecplot::get_MM(&list, index as usize);
                print!("max:{},min:{}\n", z_max, z_min);
            }

            tecplot::write_image_CM(
                &list,
                z_max,
                z_min,
                cols as usize,
                rows as usize,
                zbed_one_pixel_upto as usize,
                zbed_filter_f64,
                zbed_filename,
                z_type,
                index,
                el_x,
                el_y,
                w as usize,
                h as usize,
            );
        }
    }
}
fn yl_pollution(input: &String) {
    let mut data: String = String::from("");
    data = fs::read_to_string(input).unwrap();
    // data = match data {
    //     Ok(ddd) => ddd,
    //     Err(e) => panic!("读取JSON文件错误 \n {}", e),
    // };
    // println!("文件打开成功：{:?}", data);

    let abc = match get_args(data.as_str()) {
        Ok(v) => v,
        Err(e) => panic!("Problem of input JSON: 检查是否正确 \n {:?}", e),
    };

    let filename = abc.get("file_dem").unwrap().as_str().unwrap();
    let filename1 = abc.get("file_dat").unwrap().as_str().unwrap();

    let output = abc.get("output").unwrap();
    let zbed = output.get("pollution").unwrap();
    let zbed_filename = zbed.get("filename").unwrap().as_str().unwrap();
    let zbed_one_pixel_upto = zbed.get("onepixel").unwrap().as_i64().unwrap() as i32;
    // let cols = zbed.get("cols").unwrap().as_i64().unwrap() as i32;
    // let rows = zbed.get("rows").unwrap().as_i64().unwrap() as i32;
    let zbed_filter_f64 = zbed.get("filter").unwrap().as_f64().unwrap();
    // let zbed_filter_f64 = zbed_filter_str.parse::<f64>().unwrap();
    let mut z_max = zbed.get("max").unwrap().as_f64().unwrap();
    let mut z_min = zbed.get("min").unwrap().as_f64().unwrap();
    let z_type = zbed.get("type").unwrap().as_str().unwrap();
    let z_global_MM = zbed.get("global_MM").unwrap().as_bool().unwrap();

    //=======================================================================
    //=== 输入参数
    // let filename = "1.asc";
    // let filename1 = "1.dat";

    // let zbed_filename = "zbed.png";
    // let uv_filename = "uv.png";

    // let one_pixel_upto = 40;
    // let filter = 0.01;

    // let type_cm = true;
    // let type_arrow = true;
    //=======================================================================

    let (list, rows, cols) = get_dem(filename);
    let z = get_1data_from_file(filename1, cols + 2, rows + 2);

    //=======================================================================
    //=== 输入 max ,min of z,u ,v ,uv
    // let (z_max, z_min) = get_MM(&z, &list, cols, rows);
    // let (u_max, u_min) = get_MM(&u, &list, cols, rows);
    // let (v_max, v_min) = get_MM(&v, &list, cols, rows);
    // // print!("v.max:{},v.min:{}\n", v_max, v_min);

    // let uv_max: f64;
    // let uv_min: f64;
    // if (u_max > v_max) {
    //     uv_max = u_max;
    // } else {
    //     uv_max = v_max;
    // }

    // if (u_min < v_min) {
    //     uv_min = u_min;
    // } else {
    //     uv_min = v_min;
    // }
    //=======================================================================

    if z_global_MM == false {
        (z_max, z_min) = get_MM(&z, &list, cols, rows);
        print!("max:{},min:{}\n", z_max, z_min);
    }

    write_image_CM(
        &z,
        &list,
        z_max,
        z_min,
        cols,
        rows,
        zbed_one_pixel_upto,
        zbed_filter_f64,
        zbed_filename,
        z_type,
    );
}

fn yl_pollution_without_dem(input: &String) {
    let mut data: String = String::from("");
    data = fs::read_to_string(input).unwrap();
    // data = match data {
    //     Ok(ddd) => ddd,
    //     Err(e) => panic!("读取JSON文件错误 \n {}", e),
    // };
    // println!("文件打开成功：{:?}", data);

    let abc = match get_args(data.as_str()) {
        Ok(v) => v,
        Err(e) => panic!("Problem of input JSON: 检查是否正确 \n {:?}", e),
    };

    // let filename = abc.get("file_dem").unwrap().as_str().unwrap();
    let filename1 = abc.get("file_dat").unwrap().as_str().unwrap();

    let output = abc.get("output").unwrap();
    let zbed = output.get("pollution").unwrap();
    let zbed_filename = zbed.get("filename").unwrap().as_str().unwrap();
    let zbed_one_pixel_upto = zbed.get("onepixel").unwrap().as_i64().unwrap() as i32;
    let cols = zbed.get("cols").unwrap().as_i64().unwrap() as i32;
    let rows = zbed.get("rows").unwrap().as_i64().unwrap() as i32;
    let zbed_filter_f64 = zbed.get("filter").unwrap().as_f64().unwrap();
    // let zbed_filter_f64 = zbed_filter_str.parse::<f64>().unwrap();
    let mut z_max = zbed.get("max").unwrap().as_f64().unwrap();
    let mut z_min = zbed.get("min").unwrap().as_f64().unwrap();
    let z_type = zbed.get("type").unwrap().as_str().unwrap();
    let z_global_MM = zbed.get("global_MM").unwrap().as_bool().unwrap();

    //=======================================================================
    //=== 输入参数
    // let filename = "1.asc";
    // let filename1 = "1.dat";

    // let zbed_filename = "zbed.png";
    // let uv_filename = "uv.png";

    // let one_pixel_upto = 40;
    // let filter = 0.01;

    // let type_cm = true;
    // let type_arrow = true;
    //=======================================================================

    // let (list, rows, cols) = get_dem(filename);
    let z = get_1data_from_file(filename1, cols + 2, rows + 2);

    //=======================================================================
    //=== 输入 max ,min of z,u ,v ,uv
    // let (z_max, z_min) = get_MM(&z, &list, cols, rows);
    // let (u_max, u_min) = get_MM(&u, &list, cols, rows);
    // let (v_max, v_min) = get_MM(&v, &list, cols, rows);
    // // print!("v.max:{},v.min:{}\n", v_max, v_min);

    // let uv_max: f64;
    // let uv_min: f64;
    // if (u_max > v_max) {
    //     uv_max = u_max;
    // } else {
    //     uv_max = v_max;
    // }

    // if (u_min < v_min) {
    //     uv_min = u_min;
    // } else {
    //     uv_min = v_min;
    // }
    //=======================================================================

    if z_global_MM == false {
        (z_max, z_min) = get_MM_without_dem(&z, cols, rows);
        print!("max:{},min:{}\n", z_max, z_min);
    }
    write_image_CM_without_dem(
        &z,
        z_max,
        z_min,
        cols,
        rows,
        zbed_one_pixel_upto,
        zbed_filter_f64,
        zbed_filename,
        z_type,
    );
}

fn yl_water(file_input: &String) {
    let mut data: String = String::from("");
    data = fs::read_to_string(file_input).unwrap();
    // data = match data {
    //     Ok(ddd) => ddd,
    //     Err(e) => panic!("读取JSON文件错误 \n {}", e),
    // };
    // println!("文件打开成功：{:?}", data);

    let abc = match get_args(data.as_str()) {
        Ok(v) => v,
        Err(e) => panic!("Problem of input JSON: 检查是否正确 \n {:?}", e),
    };

    let filename = abc.get("file_dem").unwrap().as_str().unwrap();
    let filename1 = abc.get("file_dat").unwrap().as_str().unwrap();

    let output = abc.get("output").unwrap();

    let zbed = output.get("zbed").unwrap();
    let zbed_filename = zbed.get("filename").unwrap().as_str().unwrap();
    let zbed_one_pixel_upto = zbed.get("onepixel").unwrap().as_i64().unwrap() as i32;
    let zbed_filter_f64 = zbed.get("filter").unwrap().as_f64().unwrap();
    // let zbed_filter_f64 = zbed_filter_str.parse::<f64>().unwrap();
    let mut z_max = zbed.get("max").unwrap().as_f64().unwrap();
    let mut z_min = zbed.get("min").unwrap().as_f64().unwrap();
    let z_type = zbed.get("type").unwrap().as_str().unwrap();
    let z_global_MM = zbed.get("global_MM").unwrap().as_bool().unwrap();

    let uv_obj = output.get("uv");
    let uv_bool = match uv_obj {
        Some(b) => true,
        None => false,
    };
    print!("uv is object ={uv_bool}\n");
    let mut uv;
    let mut uv_filename = "asdfa";
    let mut uv_one_pixel_upto = 1;
    let mut uv_filter_f64 = 0.0;

    let mut uv_max = 0.0;
    let mut uv_min = 0.0;
    let mut uv_type: &str = "";
    let mut uv_filter_filed = "z";
    let mut uv_global_MM = false;
    if uv_bool {
        uv = output.get("uv").unwrap();
        uv_filename = uv.get("filename").unwrap().as_str().unwrap();
        uv_one_pixel_upto = uv.get("onepixel").unwrap().as_i64().unwrap() as i32;
        uv_filter_f64 = uv.get("filter").unwrap().as_f64().unwrap();
        // let uv_filter_f64 = uv_filter_str.parse::<f64>().unwrap();
        uv_max = uv.get("max").unwrap().as_f64().unwrap();
        uv_min = uv.get("min").unwrap().as_f64().unwrap();
        uv_type = uv.get("type").unwrap().as_str().unwrap();
        uv_filter_filed = uv.get("filter_filed").unwrap().as_str().unwrap();
        uv_global_MM = zbed.get("global_MM").unwrap().as_bool().unwrap();
    }
    //=======================================================================
    //=== 输入参数
    // let filename = "1.asc";
    // let filename1 = "1.dat";

    // let zbed_filename = "zbed.png";
    // let uv_filename = "uv.png";

    // let one_pixel_upto = 40;
    // let filter = 0.01;

    // let type_cm = true;
    // let type_arrow = true;
    //=======================================================================

    let (list, rows, cols) = get_dem(filename);
    let (z, u, v) = get_data_from_file(filename1, cols + 2, rows + 2);

    //=======================================================================
    //=== 输入 max ,min of z,u ,v ,uv
    if z_global_MM == false {
        (z_max, z_min) = get_MM(&z, &list, cols, rows);
    }
    if uv_global_MM == false {
        let (u_max, u_min) = get_MM(&u, &list, cols, rows);
        let (v_max, v_min) = get_MM(&v, &list, cols, rows);
        if (u_max > v_max) {
            uv_max = u_max;
        } else {
            uv_max = v_max;
        }

        if (u_min < v_min) {
            uv_min = u_min;
        } else {
            uv_min = v_min;
        }
        // print!("v.max:{},v.min:{}\n", v_max, v_min);
    }

    //=======================================================================
    println!("z max :{z_max},min:{z_min}\n UV_max:{uv_max},min:{uv_min}\n");
    write_image_CM(
        &z,
        &list,
        z_max,
        z_min,
        cols,
        rows,
        zbed_one_pixel_upto,
        zbed_filter_f64,
        zbed_filename,
        "blue",
    );
    print!("start UV  cm\n");
    if uv_bool {
        let mut f_list = z.clone();
        let mut f_max = z_max;
        let mut f_min = z_min;
        if uv_filter_filed == "uv" {
            f_list = get_vec2_array_M(&u, &v);
            f_max = uv_max;
            f_min = uv_min;
        }

        if uv_type == "arrow" {
            write_image_arrow(
                &u,
                &v,
                &list,
                uv_max,
                uv_min,
                // u_max,
                // u_min,
                // v_max,
                // v_min,
                cols,
                rows,
                uv_one_pixel_upto,
                uv_filename,
                &f_list,
                f_max,
                f_min,
                uv_filter_f64,
            );
        } else {
            write_image_CM(
                &z,
                &list,
                uv_max,
                uv_min,
                cols,
                rows,
                uv_one_pixel_upto,
                uv_filter_f64,
                uv_filename,
                "cm",
            );
        }
    }
}
